@@ -92,7 +92,12 @@ DOCUMENTATION__oauth_cookie = SwaggerDocumentation(
         method=REST__POST,
         body=[
             ARG_RES__username,
-            ARG_RES__password
+            ARG_RES__password,
+            SwaggerArgumentResponse(
+                name="remember_me",
+                arg_type=bool,
+                description="Whether or not the returned cookie will act as a remember me cookie"
+            )
         ]
     )
 )
